@@ -60,7 +60,8 @@ kpToolSelectionDestroyCommand::kpToolSelectionDestroyCommand (const QString &nam
         kpCommandEnvironment *environ)
     : kpNamedCommand (name, environ),
       m_pushOntoDocument (pushOntoDocument),
-      m_oldSelectionPtr (0)
+      m_oldSelectionPtr (0),
+      m_textRow(0), m_textCol(0)
 {
 }
 
